@@ -1,5 +1,12 @@
+/**
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
+ *
+ * Version: 5.8.2 (2021-06-23)
+ */
 (function () {
-var pagebreak = (function () {
     'use strict';
 
     var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
@@ -12,24 +19,22 @@ var pagebreak = (function () {
     var shouldSplitBlock = function (editor) {
       return editor.getParam('pagebreak_split_block', false);
     };
-    var Settings = {
-      getSeparatorHtml: getSeparatorHtml,
-      shouldSplitBlock: shouldSplitBlock
-    };
 
-    var getPageBreakClass = function () {
-      return 'mce-pagebreak';
-    };
-    var getPlaceholderHtml = function () {
-      return '<img src="' + global$1.transparentSrc + '" class="' + getPageBreakClass() + '" data-mce-resize="false" data-mce-placeholder />';
+    var pageBreakClass = 'mce-pagebreak';
+    var getPlaceholderHtml = function (shouldSplitBlock) {
+      var html = '<img src="' + global$1.transparentSrc + '" class="' + pageBreakClass + '" data-mce-resize="false" data-mce-placeholder />';
+      return shouldSplitBlock ? '<p>' + html + '</p>' : html;
     };
     var setup = function (editor) {
-      var separatorHtml = Settings.getSeparatorHtml(editor);
+      var separatorHtml = getSeparatorHtml(editor);
+      var shouldSplitBlock$1 = function () {
+        return shouldSplitBlock(editor);
+      };
       var pageBreakSeparatorRegExp = new RegExp(separatorHtml.replace(/[\?\.\*\[\]\(\)\{\}\+\^\$\:]/g, function (a) {
         return '\\' + a;
       }), 'gi');
       editor.on('BeforeSetContent', function (e) {
-        e.content = e.content.replace(pageBreakSeparatorRegExp, getPlaceholderHtml());
+        e.content = e.content.replace(pageBreakSeparatorRegExp, getPlaceholderHtml(shouldSplitBlock$1()));
       });
       editor.on('PreInit', function () {
         editor.serializer.addNodeFilter('img', function (nodes) {
@@ -37,9 +42,9 @@ var pagebreak = (function () {
           while (i--) {
             node = nodes[i];
             className = node.attr('class');
-            if (className && className.indexOf('mce-pagebreak') !== -1) {
+            if (className && className.indexOf(pageBreakClass) !== -1) {
               var parentNode = node.parent;
-              if (editor.schema.getBlockElements()[parentNode.name] && Settings.shouldSplitBlock(editor)) {
+              if (editor.schema.getBlockElements()[parentNode.name] && shouldSplitBlock$1()) {
                 parentNode.type = 3;
                 parentNode.value = separatorHtml;
                 parentNode.raw = true;
@@ -54,56 +59,47 @@ var pagebreak = (function () {
         });
       });
     };
-    var FilterContent = {
-      setup: setup,
-      getPlaceholderHtml: getPlaceholderHtml,
-      getPageBreakClass: getPageBreakClass
-    };
 
     var register = function (editor) {
       editor.addCommand('mcePageBreak', function () {
-        if (editor.settings.pagebreak_split_block) {
-          editor.insertContent('<p>' + FilterContent.getPlaceholderHtml() + '</p>');
-        } else {
-          editor.insertContent(FilterContent.getPlaceholderHtml());
-        }
+        editor.insertContent(getPlaceholderHtml(shouldSplitBlock(editor)));
       });
     };
-    var Commands = { register: register };
 
     var setup$1 = function (editor) {
       editor.on('ResolveName', function (e) {
-        if (e.target.nodeName === 'IMG' && editor.dom.hasClass(e.target, FilterContent.getPageBreakClass())) {
+        if (e.target.nodeName === 'IMG' && editor.dom.hasClass(e.target, pageBreakClass)) {
           e.name = 'pagebreak';
         }
       });
     };
-    var ResolveName = { setup: setup$1 };
 
     var register$1 = function (editor) {
-      editor.addButton('pagebreak', {
-        title: 'Page break',
-        cmd: 'mcePageBreak'
+      editor.ui.registry.addButton('pagebreak', {
+        icon: 'page-break',
+        tooltip: 'Page break',
+        onAction: function () {
+          return editor.execCommand('mcePageBreak');
+        }
       });
-      editor.addMenuItem('pagebreak', {
+      editor.ui.registry.addMenuItem('pagebreak', {
         text: 'Page break',
-        icon: 'pagebreak',
-        cmd: 'mcePageBreak',
-        context: 'insert'
+        icon: 'page-break',
+        onAction: function () {
+          return editor.execCommand('mcePageBreak');
+        }
       });
     };
-    var Buttons = { register: register$1 };
 
-    global.add('pagebreak', function (editor) {
-      Commands.register(editor);
-      Buttons.register(editor);
-      FilterContent.setup(editor);
-      ResolveName.setup(editor);
-    });
     function Plugin () {
+      global.add('pagebreak', function (editor) {
+        register(editor);
+        register$1(editor);
+        setup(editor);
+        setup$1(editor);
+      });
     }
 
-    return Plugin;
+    Plugin();
 
 }());
-})();
